@@ -43,10 +43,11 @@ class Classes_meta(type):
         'fdi.dataset.testproducts': ['TP', 'TC', 'TM'],
         'fdi.dataset.datatypes': ['Vector', 'Vector2D', 'Quaternion'],
         'fdi.dataset.metadata': ['AbstractParameter', 'Parameter', 'MetaData'],
-        'fdi.dataset.numericparameter': ['NumericParameter'],
+        'fdi.dataset.numericparameter': ['NumericParameter', 'BooleanParameter'],
         'fdi.dataset.dateparameter': ['DateParameter'],
         'fdi.dataset.stringparameter': ['StringParameter'],
-        'fdi.dataset.arraydataset': ['ArrayDataset', 'Column', 'MediaWrapper'],
+        'fdi.dataset.arraydataset': ['ArrayDataset', 'Column'],
+        'fdi.dataset.mediawrapper': ['MediaWrapper'],
         'fdi.dataset.dataset': ['GenericDataset', 'CompositeDataset'],
         'fdi.dataset.tabledataset': ['TableDataset', 'IndexedTableDataset'],
         'fdi.dataset.unstructureddataset': ['UnstrcturedDataset'],
@@ -58,6 +59,7 @@ class Classes_meta(type):
         'fdi.pal.urn': ['Urn'],
         'fdi.pal.productref': ['ProductRef'],
         'fdi.pal.query':  ['AbstractQuery', 'MetaQuery', 'StorageQuery'],
+        # 'fdi.utils.common': ['UserOrGroupNotFoundError'],
     }
 
     # class list from the package
