@@ -53,7 +53,9 @@ for tn, tt in DataTypes.items():
 DataTypeNames.update({
     'NoneType': '',
     'dict': 'vector',
-    'ODict': 'vector'
+    'OrderedDict': 'vector',
+    'UserDict': 'vector',
+    'ODict': 'vector',
 })
 del tt, tn
 
@@ -221,6 +223,8 @@ class Vector(Quantifiable, Serializable, DeepEqual):
 
     __str__ = toString
 
+    string = toString
+
     def __getstate__(self):
         """ Can be encoded with serializableEncoder
         Parameters
