@@ -7,6 +7,7 @@ from .copyable import Copyable
 
 from ..utils import leapseconds
 import datetime
+from string import ascii_uppercase
 from collections import OrderedDict
 
 import logging
@@ -77,9 +78,7 @@ class FineTime(Copyable, DeepEqual, Serializable):
         Only when current TAI is 0, so a non-zero instance is immutable. Violation gets a TypeError.
         """
 
-        if not issubclass(time.__class__, int):
-            pass
-        if time is None:
+        if not time:
             setTai = 0
         elif issubclass(time.__class__, int):
             setTai = time
@@ -102,6 +101,9 @@ class FineTime(Copyable, DeepEqual, Serializable):
             try:
                 d = datetime.datetime.strptime(t, self.format)
             except ValueError:
+                if t.endswith('Z'):
+                    d = datetime.datetime.strptime(
+                        t[:-1] + ' UTC', self.format)
                 if self.format[-4] == ' ':
                     # the last three letters are tz
                     tz = self.format[-3:]
@@ -113,8 +115,9 @@ class FineTime(Copyable, DeepEqual, Serializable):
                     # format does not have tz
                     logger.warning(
                         'Time zone stripped for %s according to format.' % t)
+
                     d = datetime.datetime.strptime(
-                        t.rsplit(' ', 1)[0], self.format)
+                        t.rsplit(' ', 1)[0].strip(ascii_uppercase), self.format)
             d1 = d.replace(tzinfo=datetime.timezone.utc)
             setTai = self.datetimeToFineTime(d1)
         try:
@@ -206,6 +209,8 @@ class FineTime(Copyable, DeepEqual, Serializable):
             s = tais
         return s
 
+    string = toString
+
     def __repr__(self):
         return self.toString(level=2)
 
