@@ -4,6 +4,7 @@ from .metadata import Parameter
 from .typecoded import Typecoded
 
 from collections import OrderedDict
+from itertools import filterfalse
 import logging
 # create logger
 logger = logging.getLogger(__name__)
@@ -21,9 +22,20 @@ class StringParameter(Parameter, Typecoded):
                  valid=None,
                  typecode='B',
                  **kwds):
+
+        typ_ = kwds.pop('typ_', 'string')
+        # collect args-turned-local-variables.
+        args = OrderedDict(filterfalse(
+            lambda x: x[0] in ('self', '__class__', 'kwds'),
+            locals().items())
+        )
+        args.update(kwds)
+
         self.setTypecode(typecode)
         super().__init__(
-            value=value, description=description, typ_='string', default=default, valid=valid, typecode=typecode, **kwds)
+            value=value, description=description, typ_=typ_, default=default, valid=valid, typecode=typecode)
+        # Must overwrite the self._all_attrs set by supera()
+        self._all_attrs = args
 
     def __getstate__(self):
         """ Can be encoded with serializableEncoder """
