@@ -5,8 +5,11 @@ logger = logging.getLogger(__name__)
 #logger.debug('level %d' %  (logger.getEffectiveLevel()))
 
 
-class Typed(object):
-    """ An object of specifiable kinds. """
+class Typed():
+    """ An object of specifiable kinds.
+
+    This class is for parameters, not for products/datasets to make 'type' MDP.
+    """
 
     def __init__(self, typ_=None, **kwds):
         """ Has a type.
@@ -17,9 +20,9 @@ class Typed(object):
         -------
         """
 
-        self.setType(typ_)
         #print(__name__ + str(kwds))
-        super(Typed, self).__init__(**kwds)
+        super().__init__(**kwds)
+        self.setType(typ_)
 
     @property
     def type(self):
