@@ -24,7 +24,7 @@ class User():
 
     def is_correct_password(self, plaintext_password):
 
-        return check_password_hash(plaintext_password, self.hashed_password)
+        return check_password_hash(self.hashed_password, plaintext_password)
 
     def __repr__(self):
         return f'<User: {self.username}>'
@@ -47,14 +47,22 @@ def getUsers(pc):
     return users
 
 
+@auth.get_user_roles
+def get_user_roles(user):
+    return user.role
+
+
 @auth.verify_password
 def verify_password(username, password):
-
     users = current_app.config['USERS']
-    current_app.logger.debug('verify user/pass %s %s vs. %s' % (
+    # return users[username]
+    current_app.logger.debug('verify user/pass "%s" "%s" vs. %s' % (
         username, password, str(users)))
     if username in users and users[username].password == password:
+        current_app.logger.debug('approved '+username)
         return users[username]
+    else:
+        return False
 
 # open text passwd
 # @auth.verify_password
