@@ -1,15 +1,17 @@
 # -*- coding: utf-8 -*-
 
 from .getswag import swag
-from .httppool_server import resp, excp, checkpath, unauthorized, check_readonly
+from .httppool_server import resp, excp, checkpath, check_readonly
 from ..model.user import auth, getUsers
+from ..._version import __version__
 from ...dataset.deserialize import deserialize_args
 from ...pal.poolmanager import PoolManager as PM, DEFAULT_MEM_POOL
 from ...pal.productpool import PoolNotFoundError
 from ...pal.webapi import WebAPI
 from ...pal.urn import parseUrn
 
-from flask import Blueprint, jsonify, request, current_app, url_for
+from flask import Blueprint, jsonify, request, current_app, url_for, abort
+from werkzeug.exceptions import HTTPException
 # from flasgger import swag_from
 
 import shutil
@@ -17,6 +19,7 @@ import time
 import copy
 import json
 import os
+from os.path import join, expandvars
 from itertools import chain
 from http import HTTPStatus
 
@@ -73,13 +76,13 @@ def logout():
     return resp(401, 'OK. Bye.', msg, ts)
 
 ######################################
-#### /  get_pools   ####
+####   get_pools_url   ####
 ######################################
 
 
 @ pools_api.route('', methods=['GET'])
 def get_pools_url():
-    """ Get names of all pools, registered or not.
+    """ Get names and urls of all pools, registered or not.
     """
     logger = current_app.logger
 
@@ -93,7 +96,12 @@ def get_pools_url():
         res = dict((x, request.base_url+'/'+x) for x in result)
     else:
         res = {}
-    msg = '%d pools found.' % len(result)
+
+    dvers = expandvars('$DOCKER_VERSION')
+    svers = expandvars('$SERVER_VERSION')
+
+    msg = '%d pools found. Versiosn: fdi %s docker %s pool server %s' % (
+        len(result), __version__, dvers, svers)
     code = 200
     return resp(code, res, msg, ts)
 
@@ -130,7 +138,7 @@ def get_name_all_pools(path):
     os.makedirs(path, exist_ok=True)
     allfilelist = os.listdir(path)
     for file in allfilelist:
-        filepath = os.path.join(path, file)
+        filepath = join(path, file)
         if os.path.isdir(filepath):
             alldirs.append(file)
     current_app.logger.debug(path + ' has ' + str(alldirs))
@@ -141,7 +149,7 @@ def get_name_all_pools(path):
 ######################################
 
 
-# @ pools_api.route('', methods=['GET'])
+# @ pools_api.route('/pools', methods=['GET'])
 @ pools_api.route('/pools/', methods=['GET'])
 @ auth.login_required(role=['read_only', 'read_write'])
 def get_registered_pools():
@@ -165,6 +173,7 @@ def get_registered_pools():
 
 
 @ pools_api.route('/pools/register_all', methods=['PUT'])
+# @ pools_api.route('/pools/register_all/', methods=['PUT'])
 @auth.login_required(role='read_write')
 def register_all():
     """ Register (Load) all pools on tme server.
@@ -215,6 +224,7 @@ def load_pools(poolnames, usr):
 
 
 @ pools_api.route('/pools/unregister_all', methods=['PUT'])
+# @ pools_api.route('/pools/unregister_all/', methods=['PUT'])
 @ auth.login_required(role='read_write')
 def unregister_all():
 
@@ -259,6 +269,7 @@ def unregister_pools(poolnames=None):
 
 
 @ pools_api.route('/pools/wipe_all', methods=['DELETE'])
+# @ pools_api.route('/pools/wipe_all/', methods=['DELETE'])
 @ auth.login_required(role='read_write')
 def wipe_all():
     """ Remove contents of all pools.
@@ -299,7 +310,7 @@ def wipe_pools(poolnames, usr):
         thepool = all_pools[nm]
         try:
             thepool.removeAll()
-            shutil.rmtree(os.path.join(path, nm))
+            shutil.rmtree(join(path, nm))
             res = PM.remove(nm)
             if res > 1:
                 notgood.append(nm+': '+str(res))
@@ -379,6 +390,7 @@ def get_pool_info(poolname, serialize_out=False):
 ######################################
 
 @ pools_api.route('/<string:pool>', methods=['PUT'])
+# @ pools_api.route('/<string:pool>/', methods=['PUT'])
 @ auth.login_required(role='read_write')
 def register(pool):
     """ Register the given pool.
@@ -404,7 +416,7 @@ def register_pool(pool, usr):
     :returns: code, pool object if successful, message
     """
     poolname = pool
-    fullpoolpath = os.path.join(current_app.config['POOLPATH_BASE'], poolname)
+    fullpoolpath = join(current_app.config['POOLPATH_BASE'], poolname)
     poolurl = current_app.config['POOLURL_BASE'] + poolname
     makenew = usr and usr.role == 'read_write'
     try:
@@ -472,6 +484,7 @@ def unregister_pool(pool):
 ######################################
 
 
+# @ pools_api.route('/<string:pool>/hk', methods=['GET'])
 @ pools_api.route('/<string:pool>/hk/', methods=['GET'])
 def hk(pool):
     """ All kinds of pool housekeeping data.
@@ -509,10 +522,11 @@ def load_HKdata(paths, serialize_out=True):
 
 
 ######################################
-####  {pool}/api/               ####
+####  {pool}/api/        List webAPIs       ####
 ######################################
 
 
+# @ pools_api.route('/<string:pool>/api', methods=['GET'])
 @ pools_api.route('/<string:pool>/api/', methods=['GET'])
 def api_info(pool):
     """ A list of names of allowed API methods.
@@ -534,6 +548,7 @@ def api_info(pool):
 
 
 @ pools_api.route('/<string:pool>/wipe', methods=['PUT'])
+# @ pools_api.route('/<string:pool>/wipe/', methods=['PUT'])
 @ auth.login_required(role='read_write')
 def wipe(pool):
     """ Removes all contents of the pool.
@@ -562,6 +577,7 @@ def wipe(pool):
 
 
 @ pools_api.route('/<string:pool>/hk/<string:kind>', methods=['GET'])
+# @ pools_api.route('/<string:pool>/hk/<string:kind>/', methods=['GET'])
 def hk_single(pool, kind):
     """ Returns the given kind of pool housekeeping data.
     """
@@ -601,7 +617,7 @@ def load_single_HKdata(paths, serialize_out=True):
 
 
 @ pools_api.route('/<string:pool>/count/<string:data_type>', methods=['GET'])
-# @ swag_from(endp['/{pool}']['put'])
+# @ pools_api.route('/<string:pool>/count/<string:data_type>/', methods=['GET'])
 def count(pool, data_type):
     """ Returns the number of given type of data in the given pool.
 
@@ -633,7 +649,7 @@ def get_prod_count(prod_type, pool_id):
     res = 0
     nm = []
 
-    path = os.path.join(current_app.config['POOLPATH_BASE'], pool_id)
+    path = join(current_app.config['POOLPATH_BASE'], pool_id)
     if os.path.exists(path):
         for i in os.listdir(path):
             if i[-1].isnumeric() and prod_type in i:
