@@ -212,6 +212,8 @@ Storage Pools (subclasses of :class:`ProductPool`) are where data item reside. T
                 self._poolpath
             )
 
+    string = toString
+
 
 def parseUrn(urn):
     """
@@ -301,7 +303,7 @@ Examples:
         raise ValueError(
             'a pool URN can have no more than 3 \':\'.')
 
-    pr = urlparse(url)
+    pr = urlparse(url.strip())
     scheme = pr.scheme       # file
     place = pr.netloc
     # Note that trailing blank and ``/`` are ignored.
