@@ -83,7 +83,7 @@ FITS_keywords_HEASARC = {
     'ONTIME': 'observationIntegrationTime',
     'ORIENTAT': 'positionAngleAxisY',
     'PA_PNT': 'positionAnglePointing',
-    'PROGRAM': 'softwareTaskName',
+    'PROGRAM': 'program',  # softwareTaskName',
     'RA': 'rightAscension',
     'RA_NOM': 'rightAscensionNominal',
     'RA_OBJ': 'rightAscensionObserved',
@@ -129,100 +129,6 @@ FITS_keywords_Standard = {
     'TELESCOP': 'telescope',
 }
 
-# Dictionary of commonly used CLASS keywords
-#
-FITS_keywords_CLASS = {
-    'MODELNAM': 'modelName',
-    'TEMPERAT': 'temperature',
-    'MAXIS': 'MAXIS',
-    'MAXIS1': 'MAXIS1',
-    'MAXIS2': 'MAXIS2',
-    'MAXIS3': 'MAXIS3',
-    'MAXIS4': 'MAXIS4',
-    'CTYPE1': 'CTYPE1',
-    'CRVAL1': 'CRVAL1',
-    'CDELT1': 'CDELT1',
-    'CRPIX1': 'CRPIX1',
-    'CTYPE2': 'CTYPE2',
-    'CRVAL2': 'CRVAL2',
-    'CDELT2': 'CDELT2',
-    'CRPIX2': 'CRPIX2',
-    'CTYPE3': 'CTYPE3',
-    'CRVAL3': 'CRVAL3',
-    'CDELT3': 'CDELT3',
-    'CRPIX3': 'CRPIX3',
-    'CTYPE4': 'CTYPE4',
-    'CRVAL4': 'CRVAL4',
-    'CDELT4': 'CDELT4',
-    'CRPIX4': 'CRPIX4',
-    'BANDWID': 'BANDWID',
-    'RESTFREQ': 'RESTFREQ',
-    'IMAGFREQ': 'IMAGFREQ',
-    'LOFREQ': 'LOFREQ',
-    'VELOCITY': 'VELOCITY',
-    'DELTAV': 'DELTAV',
-    'BLANK': 'BLANK',
-    'OBSID': 'OBSID',
-    'APID': 'APID',
-    'BBID': 'BBID',
-    'BBTYPE': 'BBTYPE',
-    'BBNUMBER': 'BBNUMBER',
-    'SEQNUMBE': 'SEQNUMBE',
-    'BEAMEFF': 'BEAMEFF',
-    'FORWEFF': 'FORWEFF',
-    'APEREFF': 'APEREFF',
-    'ETAL': 'ETAL',
-    'ETAFSS': 'ETAFSS',
-    'ANTGAIN': 'ANTGAIN',
-    'BMAJ': 'BMAJ',
-    'BMIN': 'BMIN',
-    'BPA': 'BPA',
-    'GAINIMAG': 'GAINIMAG',
-    'TAU': 'TAU',
-    'TAUIMAGE': 'TAUIMAGE',
-    'TAUZENIT': 'TAUZENIT',
-    'MH2O': 'MH2O',
-    'HUMIDITY': 'HUMIDITY',
-    'DEWPOINT': 'DEWPOINT',
-    'PRESSURE': 'PRESSURE',
-    'TOUTSIDE': 'TOUTSIDE',
-    'WINDSPEE': 'WINDSPEE',
-    'WINDDIRE': 'WINDDIRE',
-    'SCAN': 'SCAN',
-    'SUBSCAN': 'SUBSCAN',
-    'TSYS': 'TSYS',
-    'OBSTIME': 'OBSTIME',
-    'EXPOSURE': 'EXPOSURE',
-    'DATE-OBS': 'DATE-OBS',
-    'DATE-RED': 'DATE-RED',
-    'OBJECT': 'OBJECT',
-    'LINE': 'LINE',
-    'MOLECULE': 'MOLECULE',
-    'TRANSITI': 'TRANSITI',
-    'TELESCOP': 'TELESCOP',
-    'NPHASE': 'NPHASE',
-    'DELTAF1': 'DELTAF1',
-    'PTIME1': 'PTIME1',
-    'WEIGHT1': 'WEIGHT1',
-    'DELTAF2': 'DELTAF2',
-    'PTIME2': 'PTIME2',
-    'WEIGHT2': 'WEIGHT2',
-    'THOT': 'THOT',
-    'TCOLD': 'TCOLD',
-    'OBSERVER': 'OBSERVER',
-    'PROJID': 'PROJID',
-    'OBSMODE': 'OBSMODE',
-    'TEMPSCAL': 'TEMPSCAL',
-    'TCAL': 'TCAL',
-    'TRX': 'TRX',
-    'TIMESYS': 'TIMESYS',
-    'SITELONG': 'SITELONG',
-    'SITELAT': 'SITELAT',
-    'SITEELEV': 'SITEELEV',
-    'DATAMIN': 'DATAMIN',
-    'DATAMAX': 'DATAMAX'
-}
-
 
 # Dictionary of commonly used HCSS keywords that follow a numbering pattern
 # e.g. OBSID123': 'obsid123, PROP1': 'proposal1
@@ -276,7 +182,6 @@ FITS_keywords_2 = {
 
 FITS_KEYWORDS = copy.copy(FITS_keywords_Standard)
 FITS_KEYWORDS.update(FITS_keywords_HEASARC)
-FITS_KEYWORDS.update(FITS_keywords_CLASS)
 FITS_KEYWORDS.update(FITS_keywords_Numbered)
 FITS_KEYWORDS.update(FITS_keywords_2)
 
@@ -1418,3 +1323,97 @@ FITS_keywords_HCSS = {
     'COLMIN': 'colMin',
     'COLMAX': 'colMax',
 }
+
+# Dictionary of commonly used CLASS keywords
+#
+FITS_keywords_CLASS = {
+    'MODELNAM': 'modelName',
+    'TEMPERAT': 'temperature',
+    'MAXIS': 'MAXIS',
+    'MAXIS1': 'MAXIS1',
+    'MAXIS2': 'MAXIS2',
+    'MAXIS3': 'MAXIS3',
+    'MAXIS4': 'MAXIS4',
+    'CTYPE1': 'CTYPE1',
+    'CRVAL1': 'CRVAL1',
+    'CDELT1': 'CDELT1',
+    'CRPIX1': 'CRPIX1',
+    'CTYPE2': 'CTYPE2',
+    'CRVAL2': 'CRVAL2',
+    'CDELT2': 'CDELT2',
+    'CRPIX2': 'CRPIX2',
+    'CTYPE3': 'CTYPE3',
+    'CRVAL3': 'CRVAL3',
+    'CDELT3': 'CDELT3',
+    'CRPIX3': 'CRPIX3',
+    'CTYPE4': 'CTYPE4',
+    'CRVAL4': 'CRVAL4',
+    'CDELT4': 'CDELT4',
+    'CRPIX4': 'CRPIX4',
+    'BANDWID': 'BANDWID',
+    'RESTFREQ': 'RESTFREQ',
+    'IMAGFREQ': 'IMAGFREQ',
+    'LOFREQ': 'LOFREQ',
+    'VELOCITY': 'VELOCITY',
+    'DELTAV': 'DELTAV',
+    'BLANK': 'BLANK',
+    'OBSID': 'OBSID',
+    'APID': 'APID',
+    'BBID': 'BBID',
+    'BBTYPE': 'BBTYPE',
+    'BBNUMBER': 'BBNUMBER',
+    'SEQNUMBE': 'SEQNUMBE',
+    'BEAMEFF': 'BEAMEFF',
+    'FORWEFF': 'FORWEFF',
+    'APEREFF': 'APEREFF',
+    'ETAL': 'ETAL',
+    'ETAFSS': 'ETAFSS',
+    'ANTGAIN': 'ANTGAIN',
+    'BMAJ': 'BMAJ',
+    'BMIN': 'BMIN',
+    'BPA': 'BPA',
+    'GAINIMAG': 'GAINIMAG',
+    'TAU': 'TAU',
+    'TAUIMAGE': 'TAUIMAGE',
+    'TAUZENIT': 'TAUZENIT',
+    'MH2O': 'MH2O',
+    'HUMIDITY': 'HUMIDITY',
+    'DEWPOINT': 'DEWPOINT',
+    'PRESSURE': 'PRESSURE',
+    'TOUTSIDE': 'TOUTSIDE',
+    'WINDSPEE': 'WINDSPEE',
+    'WINDDIRE': 'WINDDIRE',
+    'SCAN': 'SCAN',
+    'SUBSCAN': 'SUBSCAN',
+    'TSYS': 'TSYS',
+    'OBSTIME': 'OBSTIME',
+    'EXPOSURE': 'EXPOSURE',
+    'DATE-OBS': 'DATE-OBS',
+    'DATE-RED': 'DATE-RED',
+    'OBJECT': 'OBJECT',
+    'LINE': 'LINE',
+    'MOLECULE': 'MOLECULE',
+    'TRANSITI': 'TRANSITI',
+    'TELESCOP': 'TELESCOP',
+    'NPHASE': 'NPHASE',
+    'DELTAF1': 'DELTAF1',
+    'PTIME1': 'PTIME1',
+    'WEIGHT1': 'WEIGHT1',
+    'DELTAF2': 'DELTAF2',
+    'PTIME2': 'PTIME2',
+    'WEIGHT2': 'WEIGHT2',
+    'THOT': 'THOT',
+    'TCOLD': 'TCOLD',
+    'OBSERVER': 'OBSERVER',
+    'PROJID': 'PROJID',
+    'OBSMODE': 'OBSMODE',
+    'TEMPSCAL': 'TEMPSCAL',
+    'TCAL': 'TCAL',
+    'TRX': 'TRX',
+    'TIMESYS': 'TIMESYS',
+    'SITELONG': 'SITELONG',
+    'SITELAT': 'SITELAT',
+    'SITEELEV': 'SITEELEV',
+    'DATAMIN': 'DATAMIN',
+    'DATAMAX': 'DATAMAX'
+}
