@@ -35,9 +35,9 @@ def getConfig(name=None, conf='pns', builtin=builtin_conf):
     """ Imports a dict named [conf]config.
 
     The contents of the config are defined in the ``.config/[conf]local.py`` file. The contenss are used to update defaults in ``fdi.pns.config``.
-    Th config file directory can be modified by the environment variable ``CONF_DIR``, which if  not given or pointing to an existing directly is process owner's ``~/.config`` directory.
+    Th config file directory can be modified by the environment variable ``CONF_DIR``, which, if  not given or pointing to an existing directory, is the process owner's ``~/.config`` directory.
 
-    name: if given the poolurl in ``poolurl_of`` is returned, else construct a poolurl from the contents in dict <conf>config.
+    name: if given the poolurl in ``poolurl_of`` is returned, else construct a pooluul ending with ```/{name}``` from the contents in dict <conf>config. Default ```None```.
     conf: configuration ID. default 'pns', so the file is 'pnslocal.py'.
     """
     # default configuration is provided. Copy pns/config.py to ~/.config/pnslocal.py
@@ -84,11 +84,41 @@ def getConfig(name=None, conf='pns', builtin=builtin_conf):
         logger.warning(str(
             e) + '. Use default config in the package, such as fdi/pns/config.py. Copy it to ~/.config/[package]local.py and make persistent customization there.')
 
-    if name:
+    if name is not None:
         urlof = vars(module)['poolurl_of']
         if name in urlof:
             return urlof[name]
         else:
-            return config['httphost'] + config['baseurl'] + '/' + name
+            return config['scheme'] + '://' + \
+                config['node']['host'] + ':' + \
+                str(config['node']['port']) + \
+                config['baseurl'] + \
+                '/' + name
     else:
         return config
+
+
+def make_pool(pool, conf='pns', wipe=False):
+    """ Return a ProductStorage with given pool name or poolURL.
+
+    ;name: PoolURL, or pool name (has no "://"), in which case a pool URL is made based on the result of `getConfig(name=pool, conf=conf)`. Default is ''.
+    :conf: passed to `getconfig` to determine which configuration. Default ```pns```.
+    :wipe: whether to delete everything in the pool first.
+    """
+
+    if '://' in pool:
+        poolurl = pool
+    else:
+        poolurl = getConfig(pool)
+
+    # create a product store
+    from ..pal.productstorage import ProductStorage
+    pstore = ProductStorage(poolurl=poolurl)
+    if wipe:
+        logger.info('Wiping %s...' % str(pstore))
+        pstore.wipePool()
+        # pstore.getPool(pstore.getPools()[0]).removeAll()
+    # see what is in it.
+    # print(pstore)
+
+    return pstore
