@@ -6,8 +6,9 @@ from fdi.dataset.numericparameter import NumericParameter
 from fdi.dataset.stringparameter import StringParameter
 from fdi.dataset.eq import deepcmp
 from fdi.dataset.deserialize import serialize_args, deserialize_args
-from fdi.dataset.testproducts import get_demo_product
+from fdi.dataset.testproducts import get_demo_product, get_related_product
 from fdi.pal.productstorage import ProductStorage
+from fdi.pal.productref import ProductRef
 from fdi.pal.query import MetaQuery
 from fdi.pal.poolmanager import PoolManager, DEFAULT_MEM_POOL
 from fdi.pal.httpclientpool import HttpClientPool
@@ -52,20 +53,21 @@ def init_test():
 
 def chksa(a, k):
     p = 0
-    s = serialize_args(*a, **k)
-    if p:
-        print('s= ', s)
-    code, a1, k1 = deserialize_args(s, not_quoted=False)
-    assert code == 200
-    assert a == a1
-    assert k == k1
-    s = urllib.parse.unquote(s)
-    if p:
-        print('S= ', s)
-    code, a1, k1 = deserialize_args(s, not_quoted=True)
-    assert code == 200
-    assert a == a1
-    assert k == k1
+    for not_quoted in [False, True]:
+        s = serialize_args(*a, **k)
+        if p:
+            print('s= ', s)
+        code, a1, k1 = deserialize_args(s, not_quoted=False)
+        assert code == 200
+        assert a == a1
+        assert k == k1
+        s = urllib.parse.unquote(s)
+        if p:
+            print('S= ', s)
+        code, a1, k1 = deserialize_args(s, not_quoted=True)
+        assert code == 200
+        assert a == a1
+        assert k == k1
 
 
 def test_serialize_args():
@@ -126,7 +128,8 @@ def test_gen_url(server):
     got_webapi_url = urn2fdiurl(
         urn=sampleurn, poolurl=samplepoolurl, contents=call, method='GET')
     webapi_url = aburl + '/' + samplepoolname + '/' + 'api/' + call
-    assert got_webapi_url == webapi_url, 'Get WebAPI url error: ' + got_webapi_url
+    # '/'
+    assert got_webapi_url == webapi_url+'/', 'Get WebAPI url error: ' + got_webapi_url
 
     logger.info('Post product url')
     got_post_product_url = urn2fdiurl(
@@ -222,9 +225,11 @@ def crud_t(poolid, poolurl, local_pools_dir, pool):
     pstore.getPool(poolid).removeAll()
     assert pool.isEmpty()
 
-    tag = '==Demo ** Product=='
+    tag = '==== Demo Product ===='
     logger.info('test sample demo prod with tag: '+tag)
     sp = get_demo_product()
+    sp.refs['a_ref'] = ProductRef(get_related_product())
+
     urn = pstore.save(sp, tag=tag)
     print('Sample Prod saved with tag "%s" %s to %s' %
           (tag, urn.urn, pool.poolname))
