@@ -12,6 +12,7 @@ import sys
 import threading
 import functools
 import time
+import locale
 import array
 from math import sqrt
 from datetime import timezone
@@ -65,13 +66,15 @@ if sys.version_info[0] >= 3:  # + 0.1 * sys.version_info[1] >= 3.3:
 else:
     PY3 = False
 
+locale.setlocale(locale.LC_ALL, 'en_US.UTF-8')
+
 Classes.updateMapping()
 
 # make format output in /tmp/output.py
 mk_output = 0
 
 if mk_output:
-    with open('/tmp/output.py', 'wt') as f:
+    with open('/tmp/output.py', 'wt', encoding='utf-8') as f:
         f.write('# -*- coding: utf-8 -*-\n')
 
 if __name__ == '__main__' and __package__ is None:
@@ -1185,12 +1188,22 @@ def test_MetaData():
     ts += '\n'
     ts += v.toString(extra=True)
     if mk_output:
-        print(ts)
-        with open('/tmp/output.py', 'a') as f:
+        with open('/tmp/output.py', 'a', encoding='utf-8') as f:
             clsn = 'out_MetaData'
             f.write('%s = """%s"""\n' % (clsn, ts))
+        print(ts)
     else:
-        assert ts == out_MetaData
+        print('LOCALE', locale.getlocale())
+        if ts != out_MetaData:
+            for i, t_o in enumerate(zip(ts, out_MetaData)):
+                t, o = t_o
+                if t == o:
+                    continue
+                print(i, t, o)
+                break
+            print(ts[i:])
+            print(out_MetaData[i:])
+            assert False
 
     # listeners
     class MockMetaListener(MetaDataListener):
@@ -1553,7 +1566,7 @@ def do_ArrayDataset_func(atype):
     if mk_output:
         print(ts[i:])
     else:
-        assert ts[i:-130] == nds2
+        assert ts[i:-126] == nds2
     ts += '\n\nlevel 1\n'
     ts += x.toString(1)
     ts += '\n\nlevel 2, repr\n'
@@ -1867,6 +1880,7 @@ def test_TableDataset_func():
                     ) == TableDataset(data=[[11], [21], [31]])
 
     # toString()
+
     v = TableDataset(data=a10)
 
     check_MDP(v)
@@ -1880,6 +1894,22 @@ def test_TableDataset_func():
     ts += 'an empty level 2: \n'
     ts += TableDataset().toString(level=2)
     ts += '\n\n'
+    for n, c in {'group1.val': a10['col1'], 'group1.err': a10['col2'],
+                 'no-group.val': a10['col1'],
+                 'group2.val': a10['col1'], 'group2.err': a10['col2'],
+                 'group2.seq': a10['col2'],
+                 'group2.wgt': Column(data=['', 0.32, -9876543210], unit='g'),
+                 }.items():
+        v.addColumn(n, c)
+    ts += 'grouped column names'
+    ts += v.string(0, 'grid', 'rst', 'simple')
+    ts += v.string(0, 'grid', 'rst', 'rst')
+    ts += v.string(0, 'grid', 'rst', 'grid')
+    ts += v.string(0, 'grid', 'rst', 'fancy_grid')
+    ts += v.string(0, 'grid', 'rst', 'plain')
+    ts += v.string(0, 'grid', 'rst', 'orgtbl')
+    ts += v.string(0, 'grid', 'rst', 'psql')
+    ts += '\n\n'
     if mk_output:
         print(ts)
         with open('/tmp/output.py', 'a') as f:
